#!/usr/bin/python3

# Extract renamed tags from lintian metadata.

import json
import os

from debian.deb822 import Deb822

renames = {}


def read_desc_files(path):
    for entry in os.scandir(path):
        if entry.is_dir():
            read_desc_files(entry.path)
        elif entry.name.endswith(".tag"):
            with open(entry.path) as f:
                desc = Deb822(f)
                for renamed_from in desc.get("Renamed-From", "").splitlines():
                    if renamed_from.strip():
                        renames[renamed_from.strip()] = desc["Tag"]


read_desc_files("/usr/share/lintian/tags/")

path = os.path.dirname(os.path.realpath(__file__))

with open(os.path.join(path, "renamed-tags.json"), "w") as f:
    json.dump(renames, f, indent=4, sort_keys=True)



#!/usr/bin/python3

from setuptools import setup

setup(
    name="dulwich",
    description="Python Git Library",
    long_description="""Dulwich does this and that.
And here is a list of bullet points:
* a
* and also b
* and c
""",
    version="0.1.1",
    author="Jelmer Vernooij",
    author_email="jelmer@jelmer.uk",
    url="https://www.dulwich.io/",
)



#!/usr/bin/python3

import json
import sys
from urllib.request import urlopen

BASE_URL = (
    "https://raw.githubusercontent.com/spdx/license-list-data/master/json/"
)
LICENSES_URL = BASE_URL + "licenses.json"
EXCEPTIONS_URL = BASE_URL + "exceptions.json"

licenses_summary = json.loads(urlopen(LICENSES_URL).read())
licenses = {}
license_ids = []
for license in licenses_summary["licenses"]:
    license_ids.append(license["licenseId"])
    licenses[license["licenseId"]] = {
        "name": license["name"],
    }

exceptions = json.loads(urlopen(EXCEPTIONS_URL).read())
exception_ids = []
for exception in exceptions["exceptions"]:
    exception_ids.append(exception["licenseExceptionId"])
result = {"licenses": licenses, "exception_ids": exception_ids}
json.dump(result, sys.stdout, sort_keys=True, indent=4)
